package it.andynaz.log;

import java.io.*;
import it.andynaz.utils.*;

/**
 * Logger su file.
 * 
 * Scrive i log su un file di testo.
 * 
 * <p>Ogni costruttore ha come argomento il file su cui scrivere.</p>
 * 
 * @author andynaz
 * @version 0.1 2012/08/20
 */
public class FileLogger extends Logger{
	/**
	 * File su cui scrivere.
	 * 
	 * @since 0.1
	 */
	private File logFile;
	
	/**
	 * Costruisce un FileLogger con un nome e una configurazione.
	 * 
	 * @param name nome del Logger
	 * @param conf configurazione del Logger
	 * @param logFile file su cui scrivere i log
	 * 
	 * @since 0.1
	 */
	public FileLogger(String name, Config conf, File logFile){
		super(name, conf);
		this.logFile = logFile;
	}
	
	/**
	 * Costruisce un FileLogger con un nome.
	 * 
	 * @param name nome del Logger
	 * @param logFile file su cui scrivere i log
	 * 
	 * @since 0.1
	 */
	public FileLogger(String name, File logFile){
		this(name, null, logFile);
	}
	
	/**
	 * Costruisce un FileLogger con una configurazione.
	 * 
	 * @param conf configurazione del Logger
	 * @param logFile file su cui scrivere i log
	 * 
	 * @since 0.1
	 */
	public FileLogger(Config conf, File logFile){
		this(null, conf, logFile);
	}
	
	/**
	 * Costruisce un FileLogger.
	 * 
	 * @param logFile file su cui scrivere i log
	 * 
	 * @since 0.1
	 */
	public FileLogger(File logFile){
		this(null, null, logFile);
	}
	
	
	/**
	 * Scrive il log sul file.
	 * 
	 * <p>Nel caso in cui non riesca a scrivere il log, invoca il corrispettivo
	 * metodo <code>log</code> della classe {@link Logger}.</p>
	 * 
	 * @param log log da scrivere
	 * @param level livello del log
	 * 
	 * @since 0.1
	 */
	public void log(String log, Level level){
		Config inUseConf = getInUseConf();
		if( inUseConf.getLevel().hasToLog(level) ){
			try{
				Writer w = new FileWriter(logFile, true);
				BufferedWriter bw = new BufferedWriter(w);
				bw.write(getLogPrefix() + log);
				bw.newLine();
				bw.flush();
				bw.close();
			} catch(IOException e){
				Utils.printException("errore nella scrittura del log", e);
				super.log(log, level);
			}
		}
	}
	
}
