package it.andynaz.log;

/**
 * Elenco dei livelli di log.
 * 
 * <p>Ad ogni log &egrave; associato un valore numerico. Il log viene scritto se
 * il valore numerico &egrave; sufficientemente alto.</p>
 * 
 * <p>I livelli disponibili sono, in ordine crescente:
 * <ul>
 *   <li>FINEST</li>
 *   <li>FINE</li>
 *   <li>INFO</li>
 *   <li>DEBUG</li>
 *   <li>WARNING</li>
 *   <li>SEVERE</li>
 * </ul>
 * </p>
 * 
 * @author andynaz
 * @version 0.1 2012/08/20
 */
public enum Level{
	
	/**
	 * Livello pi&ugrave; basso.
	 * 
	 * Una configurazione con questo livello permette di registrare qualunque
	 * log.
	 * 
	 * @since 0.1
	 */
	FINEST(0),
	
	/**
	 * Livello molto basso.
	 * 
	 * @since 0.1
	 */
	FINE(2),
	
	/** 
	 * Livello di defaut.
	 * 
	 * @since 0.1
	 */
	INFO(4),
	
	/**
	 * Livello di debug: usato per correggere eventuali problemi.
	 * 
	 * @since 0.1 */
	DEBUG(6),
	
	/**
	 * Livello di allarme: dovrebbe essere usato per eventuali eccezioni
	 * catturate.
	 * 
	 * @since 0.1 */
	WARNING(8),
	
	/**
	 * Livello pi&ugrave; alto: indica un problema grave (o una condizione di
	 * uscita del programma).
	 * 
	 * @since 0.1
	 */
	SEVERE(10);
	
	/**
	 * Valore numerico del livello.
	 * 
	 * @since 0.1
	 */
	public int level;
	
	
	Level(int level){
		this.level = level;
	}
	
	/**
	 * Determina se un log debba essere scritto.
	 * 
	 * Un log viene scritto se il livello dell'evento &egrave; pi&ugrave; elevato
	 * del livello corrente.
	 * 
	 * <p>Questo metodo dovrebbe essere invocato dal livello della
	 * configurazione, passandogli il livello dell'evento.</p>
	 * 
	 * @param eventLevel livello dell'evento
	 * @return <tt>true</tt> se l'evento dovrebbe essere loggato, <tt>false</tt>
	 *   altrimenti
	 * 
	 * @since 0.1
	 */
	public boolean hasToLog(Level eventLevel){
		return this.level<=eventLevel.level;
	}
}
