package it.andynaz.utils;

import static java.lang.System.out;


/**
 * <p>Metodi utili generici.</p>
 * 
 * @author andynaz
 * @version 0.2 - 2012/07/24
 */
public abstract class Utils{
	// nasconde il costruttore
	private Utils(){}

	/**
	 * <p>Controlla se una stringa &egrave; vuota.</p>
	 * 
	 * @param s una stringa da conrollare
	 * @return <tt>true</tt> se il riferimento alla stringa &egrave; nullo e se
	 *   la stringa &egrave; vuota (ha lunghezza 0), <tt>false</tt> altrimenti
	 * 
	 * @since 0.1
	 */
	public static boolean isEmpty(String s){
		return ( s==null || s.length()==0 );
	}
	
	
	//TODO: metodo printException(String message, Throwable t, OutQualcosa out) per scrivere un qualcosa dove voglio
	/**
	 * <p>Scrive sullo standard output il log di un'eccezione o un errore,
	 * preceduti da un messaggio.</p>
	 *
	 * <p>In particolare, stampa nell'ordine
	 * <ol>
	 *   <li>il messaggio personalizzato</li>
	 *   <li>il messaggio dell'eccezione</li>
	 *   <li>lo stack trace dell'eccezione/errore</li>
	 * </ol>
	 * </p>
	 * 
	 * <p><b>Nota:</b> ogni elemento viene stampato solo se <i>significativo</i>
	 * (ovvero se non nullo e non vuoto).</p>
	 *
	 * @param message messaggio personalizzato
	 * @param t errore o eccezione da loggare
	 * 
	 * @since 0.1
	 */
	public static void printException(String message, Throwable t){
		if( !isEmpty(message) ) out.println(message);
		if( !isEmpty(t.getMessage()) ) out.println(t.getMessage());
		if( t.getStackTrace()!=null ) t.printStackTrace();
	}
	
	/**
	 * Trasforma una stringa in un intero.
	 * 
	 * Nel caso in cui non sia possibile trasformare la stringa in un intero,
	 * verr&agrave; ritornato il valore <tt>null</tt>.
	 * 
	 * <p>Nota: il metodo non lancia nessuna eccezione di tipo
	 * <code>NumberFormatException</code>.</p>
	 * 
	 * @param s stringa da parsare
	 * @return l'intero corrispondete alla stringa <tt>s</tt>, o <tt>null</tt> se
	 *   la stringa non rappresenta un intero
	 * 
	 * @since 0.2
	 */
	public static Integer parseInt(String s){
		Integer i = null;
		if( !isEmpty(s) ){
			try{
				i = new Integer(s);
			} catch(NumberFormatException e){}
		}
		return i;
	}
	
	/**
	 * Trasforma una stringa in un intero di tipo <tt>Long</tt>.
	 * 
	 * Nel caso in cui non sia possibile trasformare la stringa in un intero,
	 * verr&agrave; ritornato il valore <tt>null</tt>.
	 * 
	 * <p>Nota: il metodo non lancia nessuna eccezione di tipo
	 * {@link java.lang.NumberFormatException NumberFormatException}.</p>
	 * 
	 * @param s stringa da parsare
	 * @return l'intero corrispondete alla stringa <tt>s</tt>, o <tt>null</tt> se
	 *   la stringa non rappresenta un intero
	 * 
	 * @since 0.2
	 */
	public static Long parseLong(String s){
		Long l = null;
		if( !isEmpty(s) ){
			try{
				l = new Long(s);
			} catch(NumberFormatException e){}
		}
		return l;
	}
}
