package it.andynaz.utils;

import java.io.*;
import java.util.regex.*;


/**
 * Metodi utili per una elementare gestione di file XML.
 * 
 * Per leggere e scrivere i file XML, &egrave; possibile utilizzare i metodi
 * della classe <tt>it.andynaz.utils.UtilsIO</tt>.
 * 
 * @author andynaz
 * @version 0.3 2012/08/06
 */
public class UtilsXML{
	// nasconde il costruttore
	private UtilsXML(){}
	
	//TODO metodi del tipo replaceTag(String fileContent, String tag, int content)...
	/**
	 * Rimpiazza il contenuto di un tag in un file XML.
	 * 
	 * Si appoggia al metodo <code>replaceTag(String, String, String)</code>.
	 * 
	 * @param file file XML
	 * @param tag nome del tag
	 * @param content nuovo contenut del tag
	 * 
	 * @since 0.1
	 */
	public static void replaceTag(File file, String tag, String content){
		try{
			String fileContent = UtilsIO.readFromFile(file).toString();
			fileContent = replaceTag(fileContent, tag, content);
			UtilsIO.writeToFile(file, fileContent);
		} catch(IOException e){
			Utils.printException("PDFItem::getManifestContent", e);
		}
	}
	
	/**
	 * Rimpiazza il contenuto di un tag nel contenuto di un file XML.
	 * 
	 * &Egrave; necessario che il tag sia gi&agrave; presente nel file.
	 * 
	 * <p>Nota: viene sostituita solo la prima occorrenza del tag.</p>
	 * 
	 * @param fileContent contenuto del file XML
	 * @param tag nome del tag
	 * @param content nuovo contenut del tag
	 * @return il nuovo contenuto del file XML
	 * 
	 * @since 0.2
	 */
	public static String replaceTag(String fileContent, String tag, String content){
		return fileContent.replaceFirst("<"+tag+">.+</"+tag+">", "<"+tag+">"+content+"</"+tag+">");
	}
	
	/**
	 * Legge il contenuto di un tag da un file XML.
	 * 
	 * Si appoggia al metodo <code>readTag(String, String)</code>.
	 * 
	 * <p>Nota: il metodo legge il contenuto della prima occorrenza del tag.</p>
	 * 
	 * @param file file XML
	 * @param tag nome del tag
	 * @return il contenuto del tag (o una stringa vuota se il file o il
	 *   tag non vengono trovati)
	 * 
	 * @since 0.1
	 */
	public static String readTag(File file, String tag) throws IOException{
		return readTag(UtilsIO.readFromFile(file).toString(), tag);
	}
	
	/**
	 * Legge il contenuto di un tag dal contenuto di un file XML.
	 * 
	 * <p>Nota: il metodo legge il contenuto della prima occorrenza del tag.</p>
	 * 
	 * @param fileContent contenuto del file XML
	 * @param tag nome del tag
	 * @return il contenuto del tag (o una stringa vuota il tag non viene
	 *   trovato)
	 * 
	 * @throws NullPointerException se il tag &egrave; <tt>null</tt> o ha
	 *   lunghezza 0
	 * 
	 * @since 0.2
	 */
	public static String readTag(String fileContent, String tag){
		if( Utils.isEmpty(tag) )
			throw new NullPointerException("empty tag");
		String tagContent = "";
		StringBuilder content = new StringBuilder(fileContent);
		if( content==null || content.length()==0 )
			return "";
		Pattern p = Pattern.compile("<"+tag+">.+</"+tag+">");
		Matcher m = p.matcher(content);
		if( m.find() ){
			int l = tag.length();
		//	dLog("readTag", "tag="+tag+", content="+m.group().substring(11, m.group().length()-12));
			// elimina i tag <tag> e </tag>
			tagContent = m.group().substring(l+2, m.group().length()-l-3);
		}
		return tagContent;
	}
	
}
