package it.andynaz.utils;

import java.io.*;
import java.util.zip.*;


/**
 * Metodi utili per la gestione di file compressi.
 * 
 * @author andynaz
 * @version 0.1 - 2012/07/20
 */
public class UtilsZIP {
	// nasconde il costruttore
	private UtilsZIP(){}
	
	/**
	 * Comprime un file.
	 * 
	 * Il file creato ha lo stesso nome del file originario, con l'aggiunta del
	 * suffisso <tt>.zip</tt> e viene inserito nella stessa posizione.
	 * 
	 * @param file file da comprimere
	 * @return un oggetto File che punta al file compresso
	 * 
	 * @throws FileNotFoundException se il file non viene trovato
	 * @throws IOException in caso di errore di I/O
	 * 
	 * @see <a href="http://www.bits4beats.it/java/creare-un-file-zip-in-java/"
	 *    target="_blank">bits4beats</a>
	 * @since 0.1
	 */
	public static File createZip(File file) throws IOException {
		if( file==null )
			throw new NullPointerException();
			
		File zipFile = null;
		FileInputStream fileIS = null;
		FileOutputStream fileOS = null;
		ZipOutputStream zipOS = null;

		byte data[] = new byte[1024];

		try {
			fileIS = new FileInputStream(file);
			
			zipFile = new File(file.getParent(), file.getName()+".zip");
			fileOS = new  FileOutputStream(zipFile);
			zipOS = new ZipOutputStream(new BufferedOutputStream(fileOS));
			
			/* add zip entry */
			ZipEntry entry = new ZipEntry(file.getName());
			zipOS.putNextEntry(entry);

			int count;
			while( (count=fileIS.read(data, 0, 1024))!=-1 ){
				zipOS.write(data, 0, count);
			}
			zipOS.closeEntry();
		} finally {
			zipOS.close();
			fileIS.close();
			return zipFile;
		}
	}

}
